from poetry.console.commands.cache.list import CacheListCommand

from ..command import Command
from .clear import CacheClearCommand


class CacheCommand(Command):

    name = "cache"
    description = "Interact with Poetry's cache"

    commands = [CacheClearCommand(), CacheListCommand()]

    def handle(self):
        return self.call("help", self._config.name)



class SolverProblemError(Exception):
    def __init__(self, error):
        self._error = error

        super(SolverProblemError, self).__init__(str(error))

    @property
    def error(self):
        return self._error


class OverrideNeeded(Exception):
    def __init__(self, *overrides):
        self._overrides = overrides

    @property
    def overrides(self):
        return self._overrides
